@@ -11,7 +11,9 @@
 using namespace icu;
 
 void init_fmtable(py::module &m, py::class_<Formattable, UObject> &fmt) {
-  // icu::Formattable
+  //
+  // icu::Formattable::ISDATE
+  //
   py::enum_<Formattable::ISDATE>(
       fmt, "ISDATE", py::arithmetic(),
       "This enum is only used to let callers distinguish between the *Formattable(UDate)* constructor and the "
@@ -21,6 +23,9 @@ void init_fmtable(py::module &m, py::class_<Formattable, UObject> &fmt) {
       .value("IS_DATE", Formattable::ISDATE::kIsDate)
       .export_values();
 
+  //
+  // icu::Formattable::Type
+  //
   py::enum_<Formattable::Type>(
       fmt, "Type", py::arithmetic(),
       "Selector for flavor of data type contained within a *Formattable* object.\n\n"
@@ -48,6 +53,9 @@ void init_fmtable(py::module &m, py::class_<Formattable, UObject> &fmt) {
              "Use *get_object* to retrieve the value.")
       .export_values();
 
+  //
+  // icu::Formattable
+  //
   fmt.def(py::init<>())
       .def(py::init<UDate, Formattable::ISDATE>(), py::arg("d"), py::arg("flag"))
       .def(py::init<double>(), py::arg("d").noconvert())
@@ -65,7 +73,7 @@ void init_fmtable(py::module &m, py::class_<Formattable, UObject> &fmt) {
           }),
           py::arg("number"))
       .def(py::init<const UnicodeString &>(), py::arg("str_to_copy"))
-      .def(py::init<const Formattable &>(), py::arg("source"))
+      .def(py::init<const Formattable &>(), py::arg("other"))
       .def(py::init([](const std::vector<Formattable> &array_to_copy, int32_t count) {
              if (count == -1) {
                count = static_cast<int32_t>(array_to_copy.size());
@@ -86,36 +94,49 @@ void init_fmtable(py::module &m, py::class_<Formattable, UObject> &fmt) {
            py::arg("object_to_adopt").none(false))
       .def(py::init(
                [](const TimeZone *object_to_adopt) { return std::make_unique<Formattable>(object_to_adopt->clone()); }),
-           py::arg("object_to_adopt").none(false))
-      .def(py::self != py::self, py::arg("other"))
-      .def(py::self == py::self, py::arg("other"));
-  fmt.def("__copy__", &Formattable::clone)
-      .def(
-          "__deepcopy__", [](const Formattable &self, py::dict) { return self.clone(); }, py::arg("memo"))
-      .def(
-          "__getitem__",
-          [](Formattable &self, int32_t index) -> Formattable & {
-            ErrorCode error_code;
-            int32_t count;
-            self.getArray(count, error_code);
-            if (error_code.isFailure()) {
-              throw ICUError(error_code);
-            }
-            if (index < 0) {
-              index += count;
-            }
-            if (index < 0 || index >= count) {
-              throw py::index_error(std::to_string(index));
-            }
-            return self[index];
-          },
-          py::arg("index"));
+           py::arg("object_to_adopt").none(false));
+
+  fmt.def("__copy__", &Formattable::clone);
+
+  fmt.def(
+      "__deepcopy__", [](const Formattable &self, py::dict &) { return self.clone(); }, py::arg("memo"));
+
+  fmt.def(
+      "__eq__", [](const Formattable &self, const Formattable &other) { return self == other; }, py::is_operator(),
+      py::arg("other"));
+
+  fmt.def(
+      "__getitem__",
+      [](Formattable &self, int32_t index) -> Formattable & {
+        ErrorCode error_code;
+        int32_t count;
+        self.getArray(count, error_code);
+        if (error_code.isFailure()) {
+          throw ICUError(error_code);
+        }
+        if (index < 0) {
+          index += count;
+        }
+        if (index < 0 || index >= count) {
+          throw py::index_error(std::to_string(index));
+        }
+        return self[index];
+      },
+      py::arg("index"));
+
+  fmt.def(
+      "__ne__", [](const Formattable &self, const Formattable &other) { return self != other; }, py::is_operator(),
+      py::arg("other"));
+
   // FIXME: Implement "void icu::Formattable::adoptArray(Formattable *array, int32_t count)".
   // FIXME: Implement "void icu::Formattable::adoptObject(UObject *objectToAdopt)".
   // FIXME: Implement "void icu::Formattable::adoptString(UnicodeString *stringToAdopt)".
+
   fmt.def("clone", &Formattable::clone);
+
   // TODO: Implement "const Formattable *icu::Formattable::fromUFormattable(const UFormattable *fmt)".
   // TODO: Implement "Formattable *icu::Formattable::fromUFormattable(UFormattable *fmt)".
+
   fmt.def("get_array", [](const Formattable &self) {
     ErrorCode error_code;
     int32_t count;
@@ -129,6 +150,7 @@ void init_fmtable(py::module &m, py::class_<Formattable, UObject> &fmt) {
     }
     return result;
   });
+
   fmt.def("get_date", [](const Formattable &self) {
     ErrorCode error_code;
     auto result = self.getDate(error_code);
@@ -137,6 +159,7 @@ void init_fmtable(py::module &m, py::class_<Formattable, UObject> &fmt) {
     }
     return result;
   });
+
   fmt.def("get_decimal_number", [](Formattable &self) {
     ErrorCode error_code;
     auto str = self.getDecimalNumber(error_code);
@@ -145,6 +168,7 @@ void init_fmtable(py::module &m, py::class_<Formattable, UObject> &fmt) {
     }
     return py::str(str.data());
   });
+
   fmt.def("get_double", [](const Formattable &self) {
     ErrorCode error_code;
     auto result = self.getDouble(error_code);
@@ -153,6 +177,7 @@ void init_fmtable(py::module &m, py::class_<Formattable, UObject> &fmt) {
     }
     return result;
   });
+
   fmt.def("get_int64", [](const Formattable &self) {
     ErrorCode error_code;
     auto result = self.getInt64(error_code);
@@ -161,6 +186,7 @@ void init_fmtable(py::module &m, py::class_<Formattable, UObject> &fmt) {
     }
     return result;
   });
+
   fmt.def("get_long", [](const Formattable &self) {
     ErrorCode error_code;
     auto result = self.getLong(static_cast<UErrorCode &>(error_code));
@@ -169,6 +195,7 @@ void init_fmtable(py::module &m, py::class_<Formattable, UObject> &fmt) {
     }
     return result;
   });
+
   fmt.def(
       "get_object",
       [](const Formattable &self) -> std::variant<const BasicTimeZone *, const Calendar *, const CurrencyAmount *,
@@ -199,6 +226,7 @@ void init_fmtable(py::module &m, py::class_<Formattable, UObject> &fmt) {
         return obj;
       },
       py::return_value_policy::reference);
+
   fmt.def("get_string",
           [](const Formattable &self) -> const UnicodeString & {
             ErrorCode error_code;
@@ -219,8 +247,11 @@ void init_fmtable(py::module &m, py::class_<Formattable, UObject> &fmt) {
             return value;
           },
           py::arg("result"));
+
   fmt.def("get_type", &Formattable::getType);
+
   fmt.def("is_numeric", &Formattable::isNumeric);
+
   fmt.def(
       "set_array",
       [](Formattable &self, const std::vector<Formattable> &array, int32_t count) {
@@ -230,7 +261,9 @@ void init_fmtable(py::module &m, py::class_<Formattable, UObject> &fmt) {
         self.setArray(array.data(), count);
       },
       py::arg("array"), py::arg("count") = -1);
+
   fmt.def("set_date", &Formattable::setDate, py::arg("d"));
+
   fmt.def(
       "set_decimal_number",
       [](Formattable &self, const char *number_string) {
@@ -241,15 +274,20 @@ void init_fmtable(py::module &m, py::class_<Formattable, UObject> &fmt) {
         }
       },
       py::arg("number_string"));
+
   fmt.def("set_double", &Formattable::setDouble, py::arg("d"));
+
   fmt.def("set_int64", &Formattable::setInt64, py::arg("ll"));
+
   fmt.def("set_long", &Formattable::setLong, py::arg("l"));
+
   fmt.def(
       "set_string",
       [](Formattable &self, const _UnicodeStringVariant &string_to_copy) {
         self.setString(VARIANT_TO_UNISTR(string_to_copy));
       },
       py::arg("string_to_copy"));
+
   // TODO: Implement "UFormattable *icu::Formattable::toUFormattable()".
   // TODO: Implement "const UFormattable *icu::Formattable::toUFormattable() const".
 }
