@@ -11,12 +11,17 @@
 #include <pybind11/pybind11.h>
 #include <pybind11/stl_bind.h>
 #include <unicode/errorcode.h>
+#include <unicode/locid.h>
 #include <unicode/unistr.h>
+#include <variant>
 #include <vector>
 
 namespace py = pybind11;
 
+using _LocaleVariant = std::variant<icu::Locale, std::string>;
+
 using _UnicodeStringList = std::list<icu::UnicodeString>;
+using _UnicodeStringVariant = std::variant<icu::UnicodeString, std::u16string>;
 using _UnicodeStringVector = std::vector<icu::UnicodeString>;
 
 PYBIND11_MAKE_OPAQUE(_UnicodeStringVector);
@@ -25,14 +30,20 @@ class ICUError : public std::exception {
 public:
   explicit ICUError(const icu::ErrorCode &error_code, const char *message = "");
   explicit ICUError(UErrorCode error_code);
-  const char *what() const noexcept override { return what_.c_str(); };
   const icu::ErrorCode &get_error_code() const { return error_code_; };
   const char *get_message() const { return message_.c_str(); };
 
 private:
   icu::ErrorCode error_code_;
   std::string message_;
-  std::string what_;
 };
 
+static inline auto VARIANT_TO_LOCALE(const _LocaleVariant &x) {
+  return x.index() == 0 ? std::get<0>(x) : std::get<1>(x).c_str();
+}
+
+static inline auto VARIANT_TO_UNISTR(const _UnicodeStringVariant &x) {
+  return x.index() == 0 ? std::get<0>(x) : std::get<1>(x).c_str();
+}
+
 #endif // ICUPY_MAIN_HPP
