@@ -16,7 +16,9 @@
 using namespace icu;
 
 void init_plurrule(py::module &, py::class_<PluralRules, UObject> &pr) {
+  //
   // icu::PluralRules
+  //
   /*
   pr.def(py::init([]() {
       ErrorCode error_code;
@@ -27,13 +29,23 @@ void init_plurrule(py::module &, py::class_<PluralRules, UObject> &pr) {
       return result;
     }));
   */
-  pr.def(py::init<const PluralRules &>(), py::arg("other"))
-      .def(py::self != py::self, py::arg("other"))
-      .def(py::self == py::self, py::arg("other"));
-  pr.def("__copy__", py::overload_cast<>(&PluralRules::clone, py::const_))
-      .def(
-          "__deepcopy__", [](const PluralRules &self, py::dict) { return self.clone(); }, py::arg("memo"));
+  pr.def(py::init<const PluralRules &>(), py::arg("other"));
+
+  pr.def("__copy__", py::overload_cast<>(&PluralRules::clone, py::const_));
+
+  pr.def(
+      "__deepcopy__", [](const PluralRules &self, py::dict &) { return self.clone(); }, py::arg("memo"));
+
+  pr.def(
+      "__eq__", [](const PluralRules &self, const PluralRules &other) { return self == other; }, py::is_operator(),
+      py::arg("other"));
+
+  pr.def(
+      "__ne__", [](const PluralRules &self, const PluralRules &other) { return self != other; }, py::is_operator(),
+      py::arg("other"));
+
   pr.def("clone", py::overload_cast<>(&PluralRules::clone, py::const_));
+
   pr.def_static("create_default_rules", []() {
     ErrorCode error_code;
     auto result = PluralRules::createDefaultRules(error_code);
@@ -42,6 +54,7 @@ void init_plurrule(py::module &, py::class_<PluralRules, UObject> &pr) {
     }
     return result;
   });
+
   pr.def_static(
       "create_rules",
       [](const _UnicodeStringVariant &description) {
@@ -53,6 +66,7 @@ void init_plurrule(py::module &, py::class_<PluralRules, UObject> &pr) {
         return result;
       },
       py::arg("description"));
+
   pr.def_static(
         "for_locale",
         [](const _LocaleVariant &locale) {
@@ -78,7 +92,9 @@ void init_plurrule(py::module &, py::class_<PluralRules, UObject> &pr) {
           py::arg("locale"), py::arg("type_"))
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 50)
       ;
+
   pr.def("get_keyword_other", &PluralRules::getKeywordOther);
+
   pr.def("get_keywords", [](const PluralRules &self) {
     ErrorCode error_code;
     auto result = self.getKeywords(error_code);
@@ -87,6 +103,7 @@ void init_plurrule(py::module &, py::class_<PluralRules, UObject> &pr) {
     }
     return result;
   });
+
   pr.def(
       "get_samples",
       [](PluralRules &self, const _UnicodeStringVariant &keyword, int32_t dest_capacity) {
@@ -100,12 +117,14 @@ void init_plurrule(py::module &, py::class_<PluralRules, UObject> &pr) {
         return result;
       },
       py::arg("keyword"), py::arg("dest_capacity"));
+
   pr.def(
       "is_keyword",
       [](const PluralRules &self, const _UnicodeStringVariant &keyword) {
         return self.isKeyword(VARIANT_TO_UNISTR(keyword));
       },
       py::arg("keyword"));
+
 #if (U_ICU_VERSION_MAJOR_NUM >= 64)
   pr.def(
       "select",
@@ -133,6 +152,7 @@ void init_plurrule(py::module &, py::class_<PluralRules, UObject> &pr) {
       },
       py::arg("number"));
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 68)
+
   pr.def("select", py::overload_cast<double>(&PluralRules::select, py::const_), py::arg("number").noconvert())
       .def("select", py::overload_cast<int32_t>(&PluralRules::select, py::const_), py::arg("number"));
 }
