@@ -9,7 +9,9 @@
 using namespace icu;
 
 void init_rbbi(py::module &m) {
+  //
   // icu::BreakIterator
+  //
   py::class_<BreakIterator, UObject> bi(m, "BreakIterator");
 
   py::enum_<decltype(BreakIterator::DONE)>(bi, "BreakIterator", py::arithmetic())
@@ -17,39 +19,46 @@ void init_rbbi(py::module &m) {
              "*DONE* is returned by *previous()* and *next()* after all valid boundaries have been returned.")
       .export_values();
 
-  bi.def("__copy__", &BreakIterator::clone)
-      .def(
-          "__deepcopy__", [](const BreakIterator &self, py::dict) { return self.clone(); }, py::arg("memo"))
-      .def(
-          "__eq__", [](const BreakIterator &self, const BreakIterator &other) { return self == other; },
-          py::arg("other"))
-      .def("__iter__",
-           [](BreakIterator &self) -> BreakIterator & {
-             self.first();
-             return self;
-           })
-      .def(
-          "__ne__", [](const BreakIterator &self, const BreakIterator &other) { return self != other; },
-          py::arg("other"))
-      .def("__next__",
-           [](BreakIterator &self) {
-             auto n = self.next();
-             if (n == BreakIterator::DONE) {
-               throw py::stop_iteration();
-             }
-             return n;
-           })
-      .def("__reversed__", [](BreakIterator &self) {
-        std::vector<int32_t> result;
-        for (auto n = self.last(); n != 0 && n != BreakIterator::DONE; n = self.previous()) {
-          result.push_back(n);
-        }
-        return result;
-      });
+  bi.def("__copy__", &BreakIterator::clone);
+
+  bi.def(
+      "__deepcopy__", [](const BreakIterator &self, py::dict &) { return self.clone(); }, py::arg("memo"));
+
+  bi.def(
+      "__eq__", [](const BreakIterator &self, const BreakIterator &other) { return self == other; }, py::is_operator(),
+      py::arg("other"));
+
+  bi.def("__iter__", [](BreakIterator &self) -> BreakIterator & {
+    self.first();
+    return self;
+  });
+
+  bi.def(
+      "__ne__", [](const BreakIterator &self, const BreakIterator &other) { return self != other; }, py::is_operator(),
+      py::arg("other"));
+
+  bi.def("__next__", [](BreakIterator &self) {
+    auto n = self.next();
+    if (n == BreakIterator::DONE) {
+      throw py::stop_iteration();
+    }
+    return n;
+  });
+
+  bi.def("__reversed__", [](BreakIterator &self) {
+    std::vector<int32_t> result;
+    for (auto n = self.last(); n != 0 && n != BreakIterator::DONE; n = self.previous()) {
+      result.push_back(n);
+    }
+    return result;
+  });
+
   bi.def(
       "adopt_text", [](BreakIterator &self, CharacterIterator *it) { self.adoptText(it ? it->clone() : nullptr); },
       py::arg("it"));
+
   bi.def("clone", &BreakIterator::clone);
+
   bi.def_static(
       "create_character_instance",
       [](const _LocaleVariant &where) {
@@ -61,6 +70,7 @@ void init_rbbi(py::module &m) {
         return it;
       },
       py::arg("where"));
+
   bi.def_static(
       "create_line_instance",
       [](const _LocaleVariant &where) {
@@ -72,6 +82,7 @@ void init_rbbi(py::module &m) {
         return it;
       },
       py::arg("where"));
+
   bi.def_static(
       "create_sentence_instance",
       [](const _LocaleVariant &where) {
@@ -83,6 +94,7 @@ void init_rbbi(py::module &m) {
         return it;
       },
       py::arg("where"));
+
 #ifndef U_HIDE_DEPRECATED_API
   bi.def_static(
       "create_title_instance",
@@ -96,6 +108,7 @@ void init_rbbi(py::module &m) {
       },
       py::arg("where"));
 #endif // U_HIDE_DEPRECATED_API
+
   bi.def_static(
       "create_word_instance",
       [](const _LocaleVariant &where) {
@@ -107,9 +120,13 @@ void init_rbbi(py::module &m) {
         return it;
       },
       py::arg("where"));
+
   bi.def("current", &BreakIterator::current);
+
   bi.def("first", &BreakIterator::first);
+
   bi.def("following", &BreakIterator::following, py::arg("offset"));
+
   bi.def_static(
       "get_available_locales",
       []() {
@@ -122,6 +139,7 @@ void init_rbbi(py::module &m) {
         return result;
       },
       py::return_value_policy::reference);
+
   bi.def_static(
         "get_display_name",
         [](const _LocaleVariant &object_locale, const _LocaleVariant &display_locale,
@@ -136,6 +154,7 @@ void init_rbbi(py::module &m) {
             return BreakIterator::getDisplayName(VARIANT_TO_LOCALE(object_locale), name);
           },
           py::arg("object_locale"), py::arg("name"));
+
   bi.def(
       "get_locale",
       [](const BreakIterator &self, ULocDataLocaleType type) {
@@ -147,8 +166,10 @@ void init_rbbi(py::module &m) {
         return result;
       },
       py::arg("type_"));
+
 #if (U_ICU_VERSION_MAJOR_NUM >= 52)
   bi.def("get_rule_status", &BreakIterator::getRuleStatus);
+
   bi.def("get_rule_status_vec", [](BreakIterator &self) {
     ErrorCode error_code;
     std::vector<int32_t> result(self.getRuleStatusVec(nullptr, 0, error_code));
@@ -160,7 +181,9 @@ void init_rbbi(py::module &m) {
     return result;
   });
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 52)
+
   bi.def("get_text", &BreakIterator::getText, py::return_value_policy::reference);
+
   bi.def(
       "get_utext",
       [](const BreakIterator &self, std::optional<_UTextPtr> &fill_in) {
@@ -172,15 +195,22 @@ void init_rbbi(py::module &m) {
         return std::make_unique<_UTextPtr>(p);
       },
       py::keep_alive<0, 1>(), py::arg("fill_in"));
+
   bi.def("is_boundary", &BreakIterator::isBoundary, py::arg("offset"));
+
   bi.def("last", &BreakIterator::last);
+
   bi.def("next", py::overload_cast<int32_t>(&BreakIterator::next), py::arg("n"))
       .def("next", py::overload_cast<>(&BreakIterator::next));
+
   bi.def("preceding", &BreakIterator::preceding, py::arg("offset"));
+
   bi.def("previous", &BreakIterator::previous);
+
   // FIXME: Implement "BreakIterator& BreakIterator::refreshInputText(UText *input, UErrorCode &status)".
   // TODO: Implement "static URegistryKey BreakIterator::registerInstance(BreakIterator *toAdopt, const Locale &locale,
-  // UBreakIteratorType kind,	UErrorCode &status)".
+  //  UBreakIteratorType kind,	UErrorCode &status)".
+
   bi.def("set_text", py::overload_cast<const UnicodeString &>(&BreakIterator::setText), py::arg("text"))
       .def(
           "set_text",
@@ -192,13 +222,17 @@ void init_rbbi(py::module &m) {
             }
           },
           py::arg("text"));
+
   // TODO: Implement "static UBool BreakIterator::unregister(URegistryKey key, UErrorCode &status)".
 
+  //
   // icu::RuleBasedBreakIterator
+  //
   py::class_<RuleBasedBreakIterator, BreakIterator> rbbi(m, "RuleBasedBreakIterator");
+
   rbbi.def(
           // [2] RuleBasedBreakIterator::RuleBasedBreakIterator
-          py::init<const RuleBasedBreakIterator &>(), py::arg("that"))
+          py::init<const RuleBasedBreakIterator &>(), py::arg("other"))
       .def(
           // [3] RuleBasedBreakIterator::RuleBasedBreakIterator
           py::init([](const _UnicodeStringVariant &rules, UParseError &parse_error) {
@@ -212,33 +246,51 @@ void init_rbbi(py::module &m) {
           py::arg("rules"), py::arg("parse_error"))
       .def(
           // [4] RuleBasedBreakIterator::RuleBasedBreakIterator
-          py::init([](const std::vector<uint8_t> &compiled_rules, uint32_t rule_length) {
+          py::init([](const py::buffer &compiled_rules, uint32_t rule_length) {
+            auto info = compiled_rules.request();
             ErrorCode error_code;
-            auto result = std::make_unique<RuleBasedBreakIterator>(compiled_rules.data(), rule_length, error_code);
+            auto result = std::make_unique<RuleBasedBreakIterator>(reinterpret_cast<uint8_t *>(info.ptr), rule_length,
+                                                                   error_code);
             if (error_code.isFailure()) {
               throw ICUError(error_code);
             }
             return result;
           }),
-          py::keep_alive<0, 1>(), py::arg("compiled_rules"), py::arg("rule_length"))
-      .def(py::self != py::self, py::arg("other"))
-      .def(py::self == py::self, py::arg("other"));
+          py::keep_alive<1, 2>(), py::arg("compiled_rules"), py::arg("rule_length"));
+
+  rbbi.def(
+      "__eq__", [](const RuleBasedBreakIterator &self, const BreakIterator &other) { return self == other; },
+      py::is_operator(), py::arg("other"));
+
+  rbbi.def("__hash__", &RuleBasedBreakIterator::hashCode);
+
+  rbbi.def(
+      "__ne__", [](const RuleBasedBreakIterator &self, const BreakIterator &other) { return self != other; },
+      py::is_operator(), py::arg("other"));
+
   rbbi.def(
       "adopt_text",
       [](RuleBasedBreakIterator &self, CharacterIterator *it) { self.adoptText(it ? it->clone() : nullptr); },
       py::arg("it"));
+
   rbbi.def("clone", &RuleBasedBreakIterator::clone);
+
   rbbi.def("current", &RuleBasedBreakIterator::current);
+
   rbbi.def("first", &RuleBasedBreakIterator::first);
+
   rbbi.def("following", &RuleBasedBreakIterator::following, py::arg("offset"));
+
   rbbi.def("get_binary_rules", [](RuleBasedBreakIterator &self) {
     uint32_t length = 0;
     auto p = self.getBinaryRules(length);
-    std::vector<uint8_t> result(p, p + length);
-    return result;
+    return py::bytes(reinterpret_cast<char *>(const_cast<uint8_t *>(p)), length);
   });
+
   rbbi.def("get_rules", &RuleBasedBreakIterator::getRules);
+
   rbbi.def("get_text", &RuleBasedBreakIterator::getText, py::return_value_policy::reference);
+
   rbbi.def(
       "get_utext",
       [](const RuleBasedBreakIterator &self, std::optional<_UTextPtr> &fill_in) {
@@ -250,14 +302,22 @@ void init_rbbi(py::module &m) {
         return std::make_unique<_UTextPtr>(p);
       },
       py::keep_alive<0, 1>(), py::arg("fill_in"));
+
   rbbi.def("hash_code", &RuleBasedBreakIterator::hashCode);
+
   rbbi.def("is_boundary", &RuleBasedBreakIterator::isBoundary, py::arg("offset"));
+
   rbbi.def("last", &RuleBasedBreakIterator::last);
+
   rbbi.def("next", py::overload_cast<int32_t>(&RuleBasedBreakIterator::next), py::arg("n"))
       .def("next", py::overload_cast<>(&RuleBasedBreakIterator::next));
+
   rbbi.def("preceding", &RuleBasedBreakIterator::preceding, py::arg("offset"));
+
   rbbi.def("previous", &RuleBasedBreakIterator::previous);
+
   // FIXME: Implement "BreakIterator& refreshInputText(UText *input, UErrorCode &status)".
+
   rbbi.def("set_text", py::overload_cast<const UnicodeString &>(&RuleBasedBreakIterator::setText), py::arg("text"))
       .def(
           "set_text",
