@@ -4,9 +4,14 @@
 using namespace icu;
 
 void init_tmunit(py::module &m) {
+  //
   // icu::TimeUnit
+  //
   py::class_<TimeUnit, MeasureUnit> tu(m, "TimeUnit");
 
+  //
+  // icu::TimeUnit::UTimeUnitFields
+  //
   py::enum_<TimeUnit::UTimeUnitFields>(tu, "UTimeUnitFields", py::arithmetic(),
                                        "Constants for all the time units we supported.")
       .value("UTIMEUNIT_YEAR", TimeUnit::UTIMEUNIT_YEAR)
@@ -18,11 +23,18 @@ void init_tmunit(py::module &m) {
       .value("UTIMEUNIT_SECOND", TimeUnit::UTIMEUNIT_SECOND)
       .export_values();
 
+  //
+  // icu::TimeUnit
+  //
   tu.def(py::init<const TimeUnit &>(), py::arg("other"));
-  tu.def("__copy__", &TimeUnit::clone)
-      .def(
-          "__deepcopy__", [](const TimeUnit &self, py::dict) { return self.clone(); }, py::arg("memo"));
+
+  tu.def("__copy__", &TimeUnit::clone);
+
+  tu.def(
+      "__deepcopy__", [](const TimeUnit &self, py::dict &) { return self.clone(); }, py::arg("memo"));
+
   tu.def("clone", &TimeUnit::clone);
+
   tu.def_static(
       "create_instance",
       [](TimeUnit::UTimeUnitFields time_unit_field) {
@@ -34,5 +46,6 @@ void init_tmunit(py::module &m) {
         return result;
       },
       py::arg("time_unit_field"));
+
   tu.def("get_time_unit_field", &TimeUnit::getTimeUnitField);
 }
