@@ -13,7 +13,9 @@
 using namespace icu;
 
 void init_uniset(py::module &m) {
+  //
   // icu::UMatchDegree
+  //
   py::enum_<UMatchDegree>(m, "UMatchDegree", py::arithmetic(),
                           "Constants returned by *UnicodeMatcher::matches()* indicating the degree of match.")
       .value("U_MISMATCH", U_MISMATCH,
@@ -31,16 +33,24 @@ void init_uniset(py::module &m) {
              "known that additional characters would not alter the extent of the match.")
       .export_values();
 
+  //
   // icu::UnicodeFunctor
+  //
   py::class_<UnicodeFunctor, UObject>(m, "UnicodeFunctor");
 
+  //
   // icu::UnicodeMatcher
+  //
   py::class_<UnicodeMatcher>(m, "UnicodeMatcher");
 
+  //
   // icu::UnicodeFilter
+  //
   py::class_<UnicodeFilter, UnicodeFunctor, UnicodeMatcher>(m, "UnicodeFilter");
 
+  //
   // icu::UnicodeSet
+  //
   py::class_<UnicodeSet, UnicodeFilter> us(m, "UnicodeSet");
 
   py::enum_<decltype(UnicodeSet::MIN_VALUE)>(us, "UnicodeSet", py::arithmetic())
@@ -70,9 +80,8 @@ void init_uniset(py::module &m) {
              return result;
            }),
            py::arg("pattern"), py::arg("pos"), py::arg("options"), py::arg("symbols"))
-      .def(py::init<const UnicodeSet &>(), py::arg("other"))
-      .def(py::self != py::self, py::arg("other"))
-      .def(py::self == py::self, py::arg("other"));
+      .def(py::init<const UnicodeSet &>(), py::arg("other"));
+
   us.def(
         "__contains__",
         [](const UnicodeSet &self, const _UnicodeStringVariant &item) {
@@ -80,28 +89,35 @@ void init_uniset(py::module &m) {
         },
         py::arg("item"))
       .def(
-          "__contains__", [](const UnicodeSet &self, UChar32 item) { return self.contains(item); }, py::arg("item"))
-      .def("__copy__", &UnicodeSet::clone)
-      .def(
-          "__deepcopy__", [](const UnicodeSet &self, py::dict) { return self.clone(); }, py::arg("memo"))
+          "__contains__", [](const UnicodeSet &self, UChar32 item) { return self.contains(item); }, py::arg("item"));
+
+  us.def("__copy__", &UnicodeSet::clone);
+
+  us.def(
+      "__deepcopy__", [](const UnicodeSet &self, py::dict &) { return self.clone(); }, py::arg("memo"));
+
+  us.def(
+        "__eq__", [](const UnicodeSet &self, const UnicodeSet &other) { return self == other; }, py::is_operator(),
+        py::arg("other"))
       .def(
           "__eq__", [](const UnicodeSet &self, _ConstUSetPtr &other) { return uset_equals(self.toUSet(), other); },
           py::is_operator(), py::arg("other"))
       .def(
           "__eq__", [](const UnicodeSet &self, _USetPtr &other) { return uset_equals(self.toUSet(), other); },
-          py::is_operator(), py::arg("other"))
-      .def(
-          "__getitem__",
-          [](const UnicodeSet &self, int32_t index) {
-            if (index < 0) {
-              index += self.size();
-            }
-            if (index < 0 || index >= self.size()) {
-              throw py::index_error(std::to_string(index));
-            }
-            return self.charAt(index);
-          },
-          py::arg("index"))
+          py::is_operator(), py::arg("other"));
+
+  us.def(
+        "__getitem__",
+        [](const UnicodeSet &self, int32_t index) {
+          if (index < 0) {
+            index += self.size();
+          }
+          if (index < 0 || index >= self.size()) {
+            throw py::index_error(std::to_string(index));
+          }
+          return self.charAt(index);
+        },
+        py::arg("index"))
       .def(
           "__getitem__",
           [](const UnicodeSet &self, py::slice slice) {
@@ -116,29 +132,39 @@ void init_uniset(py::module &m) {
             }
             return result;
           },
-          py::arg("slice"))
-      .def("__len__", &UnicodeSet::size)
+          py::arg("slice"));
+
+  us.def("__hash__", &UnicodeSet::hashCode);
+
+  us.def("__len__", &UnicodeSet::size);
+
+  us.def(
+        "__ne__", [](const UnicodeSet &self, const UnicodeSet &other) { return self != other; }, py::is_operator(),
+        py::arg("other"))
       .def(
           "__ne__", [](const UnicodeSet &self, _ConstUSetPtr &other) { return !uset_equals(self.toUSet(), other); },
           py::is_operator(), py::arg("other"))
       .def(
           "__ne__", [](const UnicodeSet &self, _USetPtr &other) { return !uset_equals(self.toUSet(), other); },
-          py::is_operator(), py::arg("other"))
-      .def("__repr__", [](const UnicodeSet &self) {
-        std::stringstream ss;
-        ss << "UnicodeSet(";
-        UnicodeString pattern;
-        self.toPattern(pattern, true);
-        ss << pattern;
-        ss << ")";
-        return ss.str();
-      });
+          py::is_operator(), py::arg("other"));
+
+  us.def("__repr__", [](const UnicodeSet &self) {
+    std::stringstream ss;
+    ss << "<UnicodeSet('";
+    UnicodeString pattern;
+    self.toPattern(pattern, true).findAndReplace("'", "\\'");
+    ss << pattern;
+    ss << "')>";
+    return ss.str();
+  });
+
   us.def(
         "add",
         [](UnicodeSet &self, const _UnicodeStringVariant &s) -> UnicodeSet & { return self.add(VARIANT_TO_UNISTR(s)); },
         py::arg("s"))
       .def("add", py::overload_cast<UChar32>(&UnicodeSet::add), py::arg("c"))
       .def("add", py::overload_cast<UChar32, UChar32>(&UnicodeSet::add), py::arg("start"), py::arg("end"));
+
   us.def("add_all", py::overload_cast<const UnicodeSet &>(&UnicodeSet::addAll), py::arg("c"))
       .def(
           "add_all",
@@ -146,7 +172,9 @@ void init_uniset(py::module &m) {
             return self.addAll(VARIANT_TO_UNISTR(s));
           },
           py::arg("s"));
+
   us.def("add_match_set_to", &UnicodeSet::addMatchSetTo, py::arg("to_union_to"));
+
   us.def(
       "apply_int_property_value",
       [](UnicodeSet &self, UProperty prop, int32_t value) -> UnicodeSet & {
@@ -158,6 +186,7 @@ void init_uniset(py::module &m) {
         return result;
       },
       py::arg("prop"), py::arg("value"));
+
   us.def(
         "apply_pattern",
         [](UnicodeSet &self, const _UnicodeStringVariant &pattern, ParsePosition &pos, uint32_t options,
@@ -182,6 +211,7 @@ void init_uniset(py::module &m) {
             return result;
           },
           py::arg("pattern"));
+
   us.def(
       "apply_property_alias",
       [](UnicodeSet &self, const _UnicodeStringVariant &prop, const _UnicodeStringVariant &value) -> UnicodeSet & {
@@ -193,12 +223,19 @@ void init_uniset(py::module &m) {
         return result;
       },
       py::arg("prop"), py::arg("value"));
+
   us.def("char_at", &UnicodeSet::charAt, py::arg("index"));
+
   us.def("clear", &UnicodeSet::clear);
+
   us.def("clone", &UnicodeSet::clone);
+
   us.def("clone_as_thawed", &UnicodeSet::cloneAsThawed);
+
   us.def("close_over", &UnicodeSet::closeOver, py::arg("attribute"));
+
   us.def("compact", &UnicodeSet::compact);
+
   us.def(
         "complement",
         [](UnicodeSet &self, const _UnicodeStringVariant &s) -> UnicodeSet & {
@@ -208,6 +245,7 @@ void init_uniset(py::module &m) {
       .def("complement", py::overload_cast<UChar32>(&UnicodeSet::complement), py::arg("c"))
       .def("complement", py::overload_cast<UChar32, UChar32>(&UnicodeSet::complement), py::arg("start"), py::arg("end"))
       .def("complement", py::overload_cast<>(&UnicodeSet::complement));
+
   us.def("complement_all", py::overload_cast<const UnicodeSet &>(&UnicodeSet::complementAll), py::arg("c"))
       .def(
           "complement_all",
@@ -215,6 +253,7 @@ void init_uniset(py::module &m) {
             return self.complementAll(VARIANT_TO_UNISTR(s));
           },
           py::arg("s"));
+
   us.def(
         "contains",
         [](const UnicodeSet &self, const _UnicodeStringVariant &s) { return self.contains(VARIANT_TO_UNISTR(s)); },
@@ -222,11 +261,13 @@ void init_uniset(py::module &m) {
       .def("contains", py::overload_cast<UChar32>(&UnicodeSet::contains, py::const_), py::arg("c"))
       .def("contains", py::overload_cast<UChar32, UChar32>(&UnicodeSet::contains, py::const_), py::arg("start"),
            py::arg("end"));
+
   us.def("contains_all", py::overload_cast<const UnicodeSet &>(&UnicodeSet::containsAll, py::const_), py::arg("c"))
       .def(
           "contains_all",
           [](const UnicodeSet &self, const _UnicodeStringVariant &s) { return self.containsAll(VARIANT_TO_UNISTR(s)); },
           py::arg("s"));
+
   us.def("contains_none", py::overload_cast<const UnicodeSet &>(&UnicodeSet::containsNone, py::const_), py::arg("c"))
       .def(
           "contains_none",
@@ -236,6 +277,7 @@ void init_uniset(py::module &m) {
           py::arg("s"))
       .def("contains_none", py::overload_cast<UChar32, UChar32>(&UnicodeSet::containsNone, py::const_),
            py::arg("start"), py::arg("end"));
+
   us.def("contains_some", py::overload_cast<const UnicodeSet &>(&UnicodeSet::containsSome, py::const_), py::arg("c"))
       .def(
           "contains_some",
@@ -245,30 +287,44 @@ void init_uniset(py::module &m) {
           py::arg("s"))
       .def("contains_some", py::overload_cast<UChar32, UChar32>(&UnicodeSet::containsSome, py::const_),
            py::arg("start"), py::arg("end"));
+
   us.def_static(
       "create_from", [](const _UnicodeStringVariant &s) { return UnicodeSet::createFrom(VARIANT_TO_UNISTR(s)); },
       py::arg("s"));
+
   us.def_static(
       "create_from_all", [](const _UnicodeStringVariant &s) { return UnicodeSet::createFromAll(VARIANT_TO_UNISTR(s)); },
       py::arg("s"));
+
   us.def("freeze", &UnicodeSet::freeze);
+
   us.def_static(
         "from_uset", [](_ConstUSetPtr &uset) { return UnicodeSet::fromUSet(uset); }, py::return_value_policy::reference,
         py::arg("uset"))
       .def_static(
           "from_uset", [](_USetPtr &uset) { return UnicodeSet::fromUSet(uset); }, py::return_value_policy::reference,
           py::arg("uset"));
+
   us.def("get_range_count", &UnicodeSet::getRangeCount);
+
   us.def("get_range_end", &UnicodeSet::getRangeEnd, py::arg("index"));
+
   us.def("get_range_start", &UnicodeSet::getRangeStart, py::arg("index"));
+
   us.def("hash_code", &UnicodeSet::hashCode);
+
 #if (U_ICU_VERSION_MAJOR_NUM >= 70)
   us.def("has_strings", &UnicodeSet::hasStrings);
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 70)
+
   us.def("index_of", &UnicodeSet::indexOf, py::arg("c"));
+
   us.def("is_bogus", &UnicodeSet::isBogus);
+
   us.def("is_empty", &UnicodeSet::isEmpty);
+
   us.def("is_frozen", &UnicodeSet::isFrozen);
+
   us.def(
       "matches",
       [](UnicodeSet &self, const Replaceable &text, int32_t offset, int32_t limit, UBool incremental) {
@@ -276,6 +332,7 @@ void init_uniset(py::module &m) {
         return py::make_tuple(result, offset);
       },
       py::arg("text"), py::arg("offset"), py::arg("limit"), py::arg("incremental"));
+
   us.def(
         "remove",
         [](UnicodeSet &self, const _UnicodeStringVariant &s) -> UnicodeSet & {
@@ -284,6 +341,7 @@ void init_uniset(py::module &m) {
         py::arg("s"))
       .def("remove", py::overload_cast<UChar32>(&UnicodeSet::remove), py::arg("c"))
       .def("remove", py::overload_cast<UChar32, UChar32>(&UnicodeSet::remove), py::arg("start"), py::arg("end"));
+
   us.def("remove_all", py::overload_cast<const UnicodeSet &>(&UnicodeSet::removeAll), py::arg("c"))
       .def(
           "remove_all",
@@ -291,13 +349,16 @@ void init_uniset(py::module &m) {
             return self.removeAll(VARIANT_TO_UNISTR(s));
           },
           py::arg("s"));
+
   us.def("remove_all_strings", &UnicodeSet::removeAllStrings);
+
   us.def_static(
       "resembles_pattern",
       [](const _UnicodeStringVariant &pattern, int32_t pos) {
         return UnicodeSet::resemblesPattern(VARIANT_TO_UNISTR(pattern), pos);
       },
       py::arg("pattern"), py::arg("pos"));
+
 #if (U_ICU_VERSION_MAJOR_NUM >= 69)
   us.def(
       "retain",
@@ -306,8 +367,10 @@ void init_uniset(py::module &m) {
       },
       py::arg("s"));
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 69)
+
   us.def("retain", py::overload_cast<UChar32>(&UnicodeSet::retain), py::arg("c"))
       .def("retain", py::overload_cast<UChar32, UChar32>(&UnicodeSet::retain), py::arg("start"), py::arg("end"));
+
   us.def("retain_all", py::overload_cast<const UnicodeSet &>(&UnicodeSet::retainAll), py::arg("c"))
       .def(
           "retain_all",
@@ -315,6 +378,7 @@ void init_uniset(py::module &m) {
             return self.retainAll(VARIANT_TO_UNISTR(s));
           },
           py::arg("s"));
+
   us.def("serialize", [](const UnicodeSet &self) {
     ErrorCode error_code;
     const auto length = self.serialize(nullptr, 0, error_code);
@@ -326,29 +390,40 @@ void init_uniset(py::module &m) {
     }
     return result;
   });
+
   us.def("set", &UnicodeSet::set, py::arg("start"), py::arg("end"));
+
   us.def("set_to_bogus", &UnicodeSet::setToBogus);
+
   us.def("size", &UnicodeSet::size);
+
   us.def("span", py::overload_cast<const char16_t *, int32_t, USetSpanCondition>(&UnicodeSet::span, py::const_),
          py::arg("s"), py::arg("length"), py::arg("span_condition"))
       .def("span", py::overload_cast<const UnicodeString &, int32_t, USetSpanCondition>(&UnicodeSet::span, py::const_),
            py::arg("s"), py::arg("start"), py::arg("span_condition"));
+
   us.def("span_back",
          py::overload_cast<const char16_t *, int32_t, USetSpanCondition>(&UnicodeSet::spanBack, py::const_),
          py::arg("s"), py::arg("length"), py::arg("span_condition"))
       .def("span_back",
            py::overload_cast<const UnicodeString &, int32_t, USetSpanCondition>(&UnicodeSet::spanBack, py::const_),
            py::arg("s"), py::arg("limit"), py::arg("span_condition"));
+
   us.def("to_pattern", &UnicodeSet::toPattern, py::arg("result"), py::arg("escape_unprintable") = false);
+
   us.def("to_uset", [](UnicodeSet &self) {
     auto uset = self.toUSet();
     return std::make_unique<_USetPtr>(uset);
   });
 
-  us.def_property_readonly_static("IGNORE_SPACE", [](py::object) -> int32_t { return USET_IGNORE_SPACE; });
-  us.def_property_readonly_static("CASE_INSENSITIVE", [](py::object) -> int32_t { return USET_CASE_INSENSITIVE; });
-  us.def_property_readonly_static("ADD_CASE_MAPPINGS", [](py::object) -> int32_t { return USET_ADD_CASE_MAPPINGS; });
+  us.def_property_readonly_static("IGNORE_SPACE", [](const py::object &) -> int32_t { return USET_IGNORE_SPACE; });
+
+  us.def_property_readonly_static("CASE_INSENSITIVE",
+                                  [](const py::object &) -> int32_t { return USET_CASE_INSENSITIVE; });
+
+  us.def_property_readonly_static("ADD_CASE_MAPPINGS",
+                                  [](const py::object &) -> int32_t { return USET_ADD_CASE_MAPPINGS; });
 
   us.def_property_readonly_static("SERIALIZED_STATIC_ARRAY_CAPACITY",
-                                  [](py::object) -> int32_t { return USET_SERIALIZED_STATIC_ARRAY_CAPACITY; });
+                                  [](const py::object &) -> int32_t { return USET_SERIALIZED_STATIC_ARRAY_CAPACITY; });
 }
