@@ -15,14 +15,20 @@
 using namespace icu;
 
 void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class_<UnicodeString, Replaceable> &us) {
+  //
   // icu::Replaceable
+  //
   rep.def("char32_at", &Replaceable::char32At, py::arg("offset"));
+
   rep.def(
       "char_at", [](const Replaceable &self, int32_t offset) -> uint16_t { return self.charAt(offset); },
       py::arg("offset"));
+
   rep.def("length", &Replaceable::length);
 
-  // icu::UnicodeString
+  //
+  // icu::UnicodeString::EInvariant
+  //
   py::enum_<UnicodeString::EInvariant>(
       us, "EInvariant", py::arithmetic(),
       "Constant to be used in the *UnicodeString(char *, int32_t, EInvariant)* constructor which constructs a Unicode "
@@ -31,6 +37,9 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
       .value("INVARIANT", UnicodeString::kInvariant)
       .export_values();
 
+  //
+  // icu::UnicodeString
+  //
   us.def(py::init<>())
       .def(py::init<int32_t, UChar32, int32_t>(), py::arg("capacity"), py::arg("c"), py::arg("count"))
       .def(py::init<UChar32>(), py::arg("ch"))
@@ -63,47 +72,50 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
            py::arg("src"), py::arg("src_length"), py::arg("cnv"))
       .def(py::init<const char *, int32_t, UnicodeString::EInvariant>(), py::arg("src"), py::arg("text_length"),
            py::arg("inv"))
-      .def(py::init<const UnicodeString &>(), py::arg("that"))
+      .def(py::init<const UnicodeString &>(), py::arg("other"))
       .def(py::init<const UnicodeString &, int32_t>(), py::arg("src"), py::arg("src_start"))
       .def(py::init<const UnicodeString &, int32_t, int32_t>(), py::arg("src"), py::arg("src_start"),
            py::arg("src_length"));
+
   us.def(
-        "__add__",
-        [](UnicodeString &self, const _UnicodeStringVariant &other) { return self + VARIANT_TO_UNISTR(other); },
-        py::is_operator(), py::arg("other"))
-      .def(
-          "__contains__",
-          [](const UnicodeString &self, const _UnicodeStringVariant &item) {
-            return self.indexOf(VARIANT_TO_UNISTR(item)) >= 0;
-          },
-          py::arg("item"))
-      .def("__copy__", &UnicodeString::clone)
-      .def(
-          "__deepcopy__", [](const UnicodeString &self, py::dict) { return self.clone(); }, py::arg("memo"))
-      .def(
-          "__eq__",
-          [](const UnicodeString &self, const _UnicodeStringVariant &other) {
-            return self == VARIANT_TO_UNISTR(other);
-          },
-          py::is_operator(), py::arg("other"))
-      .def(
-          "__ge__",
-          [](const UnicodeString &self, const _UnicodeStringVariant &other) {
-            return self >= VARIANT_TO_UNISTR(other);
-          },
-          py::is_operator(), py::arg("other"))
-      .def(
-          "__getitem__",
-          [](const UnicodeString &self, int32_t index) {
-            if (index < 0) {
-              index += self.length();
-            }
-            if (index < 0 || index >= self.length()) {
-              throw py::index_error(std::to_string(index));
-            }
-            return self[index];
-          },
-          py::arg("index"))
+      "__add__",
+      [](UnicodeString &self, const _UnicodeStringVariant &other) { return self + VARIANT_TO_UNISTR(other); },
+      py::is_operator(), py::arg("other"));
+
+  us.def(
+      "__contains__",
+      [](const UnicodeString &self, const _UnicodeStringVariant &item) {
+        return self.indexOf(VARIANT_TO_UNISTR(item)) >= 0;
+      },
+      py::arg("item"));
+
+  us.def("__copy__", &UnicodeString::clone);
+
+  us.def(
+      "__deepcopy__", [](const UnicodeString &self, py::dict &) { return self.clone(); }, py::arg("memo"));
+
+  us.def(
+      "__eq__",
+      [](const UnicodeString &self, const _UnicodeStringVariant &other) { return self == VARIANT_TO_UNISTR(other); },
+      py::is_operator(), py::arg("other"));
+
+  us.def(
+      "__ge__",
+      [](const UnicodeString &self, const _UnicodeStringVariant &other) { return self >= VARIANT_TO_UNISTR(other); },
+      py::is_operator(), py::arg("other"));
+
+  us.def(
+        "__getitem__",
+        [](const UnicodeString &self, int32_t index) {
+          if (index < 0) {
+            index += self.length();
+          }
+          if (index < 0 || index >= self.length()) {
+            throw py::index_error(std::to_string(index));
+          }
+          return self[index];
+        },
+        py::arg("index"))
       .def(
           "__getitem__",
           [](const UnicodeString &self, py::slice slice) {
@@ -118,74 +130,84 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
             }
             return result;
           },
-          py::arg("slice"))
-      .def(
-          "__gt__",
-          [](const UnicodeString &self, const _UnicodeStringVariant &other) { return self > VARIANT_TO_UNISTR(other); },
-          py::is_operator(), py::arg("other"))
-      .def(
-          "__iadd__",
-          [](UnicodeString &self, const _UnicodeStringVariant &other) { return self += VARIANT_TO_UNISTR(other); },
-          py::is_operator(), py::arg("other"))
-      .def(
-          "__iadd__", [](UnicodeString &self, UChar32 other) { return self += other; }, py::is_operator(),
-          py::arg("other"))
-      .def(
-          "__le__",
-          [](const UnicodeString &self, const _UnicodeStringVariant &other) {
-            return self <= VARIANT_TO_UNISTR(other);
-          },
-          py::is_operator(), py::arg("other"))
-      .def("__len__", [](const UnicodeString &self) { return self.length(); })
-      .def(
-          "__lt__",
-          [](const UnicodeString &self, const _UnicodeStringVariant &other) { return self < VARIANT_TO_UNISTR(other); },
-          py::is_operator(), py::arg("other"))
-      .def(
-          "__ne__",
-          [](const UnicodeString &self, const _UnicodeStringVariant &other) {
-            return self != VARIANT_TO_UNISTR(other);
-          },
-          py::is_operator(), py::arg("other"))
-      .def("__repr__",
-           [](const UnicodeString &self) {
-             std::stringstream ss;
-             ss << "UnicodeString('";
-             auto it = UCharCharacterIterator(self.getBuffer(), self.length());
-             const char *prefix;
-             int w;
-             for (auto c = it.first32(); it.hasNext(); c = it.next32()) {
-               if (c >= 0x20 && c <= 0x7e) {
-                 if (c == '\'') {
-                   ss << "\\'";
-                 } else {
-                   ss << static_cast<char>(c);
-                 }
-               } else {
-                 if (c <= 0xff) {
-                   prefix = "\\x";
-                   w = 2;
-                 } else if (c <= 0xffff) {
-                   prefix = "\\u";
-                   w = 4;
-                 } else {
-                   prefix = "\\U";
-                   w = 8;
-                 }
-                 ss << prefix << std::nouppercase << std::hex << std::setw(w) << std::setfill('0') << c;
-               }
-             }
-             ss << "')";
-             return ss.str();
-           })
-      .def("__str__", [](const UnicodeString &self) {
-        std::string result;
-        self.toUTF8String(result);
-        return result;
-      });
+          py::arg("slice"));
+
+  us.def(
+      "__gt__",
+      [](const UnicodeString &self, const _UnicodeStringVariant &other) { return self > VARIANT_TO_UNISTR(other); },
+      py::is_operator(), py::arg("other"));
+
+  us.def("__hash__", &UnicodeString::hashCode);
+
+  us.def(
+      "__iadd__",
+      [](UnicodeString &self, const _UnicodeStringVariant &other) { return self += VARIANT_TO_UNISTR(other); },
+      py::is_operator(), py::arg("other"));
+
+  us.def(
+      "__iadd__", [](UnicodeString &self, UChar32 other) { return self += other; }, py::is_operator(),
+      py::arg("other"));
+
+  us.def(
+      "__le__",
+      [](const UnicodeString &self, const _UnicodeStringVariant &other) { return self <= VARIANT_TO_UNISTR(other); },
+      py::is_operator(), py::arg("other"));
+
+  us.def("__len__", [](const UnicodeString &self) { return self.length(); });
+
+  us.def(
+      "__lt__",
+      [](const UnicodeString &self, const _UnicodeStringVariant &other) { return self < VARIANT_TO_UNISTR(other); },
+      py::is_operator(), py::arg("other"));
+
+  us.def(
+      "__ne__",
+      [](const UnicodeString &self, const _UnicodeStringVariant &other) { return self != VARIANT_TO_UNISTR(other); },
+      py::is_operator(), py::arg("other"));
+
+  us.def("__repr__", [](const UnicodeString &self) {
+    std::stringstream ss;
+    ss << "UnicodeString('";
+    const auto text_length = self.length();
+    auto it = UCharCharacterIterator(self.getBuffer(), text_length);
+    const char *prefix;
+    int w;
+    for (auto c = it.first32(); it.hasNext(); c = it.next32()) {
+      if (c >= 0x20 && c <= 0x7e) {
+        if (c == '\'') {
+          ss << "\\'";
+        } else {
+          ss << static_cast<char>(c);
+        }
+      } else {
+        if (c <= 0xff) {
+          prefix = "\\x";
+          w = 2;
+        } else if (c <= 0xffff) {
+          prefix = "\\u";
+          w = 4;
+        } else {
+          prefix = "\\U";
+          w = 8;
+        }
+        ss << prefix << std::nouppercase << std::hex << std::setw(w) << std::setfill('0') << c;
+      }
+    }
+    ss << "', text_length=" << std::dec << text_length;
+    ss << ")";
+    return ss.str();
+  });
+
+  us.def("__str__", [](const UnicodeString &self) {
+    std::string result;
+    self.toUTF8String(result);
+    return result;
+  });
+
   // us.def(
   //       // [1] append(char16_t srcChar)
   //       "append", py::overload_cast<char16_t>(&UnicodeString::append), py::arg("src_char"))
+
   us.def(
         // [2] append(const char16_t *srcChars, int32_t srcStart, int32_t srcLength)
         "append", py::overload_cast<const char16_t *, int32_t, int32_t>(&UnicodeString::append), py::arg("src_chars"),
@@ -211,6 +233,7 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
       .def(
           // [6] append(UChar32 srcChar)
           "append", py::overload_cast<UChar32>(&UnicodeString::append), py::arg("src_char"));
+
   us.def(
         // [1] caseCompare(const UnicodeString &text, uint32_t options)
         "case_compare",
@@ -251,6 +274,7 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
           "case_compare",
           py::overload_cast<int32_t, int32_t, const UnicodeString &, uint32_t>(&UnicodeString::caseCompare, py::const_),
           py::arg("start"), py::arg("length"), py::arg("src_text"), py::arg("options"));
+
   us.def(
       "case_compare_between",
       [](const UnicodeString &self, int32_t start, int32_t limit, const _UnicodeStringVariant &src_text,
@@ -259,7 +283,9 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
       },
       py::arg("start"), py::arg("limit"), py::arg("src_text"), py::arg("src_start"), py::arg("src_limit"),
       py::arg("options"));
+
   us.def("clone", &UnicodeString::clone);
+
   us.def(
         // [1] compare(const UnicodeString &text)
         "compare",
@@ -294,6 +320,7 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
           // [6] compare(int32_t start, int32_t length, const UnicodeString &text)
           "compare", py::overload_cast<int32_t, int32_t, const UnicodeString &>(&UnicodeString::compare, py::const_),
           py::arg("start"), py::arg("length"), py::arg("text"));
+
   us.def(
       "compare_between",
       [](const UnicodeString &self, int32_t start, int32_t limit, const _UnicodeStringVariant &src_text,
@@ -301,6 +328,7 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
         return self.compareBetween(start, limit, VARIANT_TO_UNISTR(src_text), src_start, src_limit);
       },
       py::arg("start"), py::arg("limit"), py::arg("src_text"), py::arg("src_start"), py::arg("src_limit"));
+
   us.def(
         // [1] compareCodePointOrder(const UnicodeString &text)
         "compare_code_point_order",
@@ -339,6 +367,7 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
           py::overload_cast<int32_t, int32_t, const UnicodeString &, int32_t, int32_t>(
               &UnicodeString::compareCodePointOrder, py::const_),
           py::arg("start"), py::arg("length"), py::arg("src_text"), py::arg("src_start"), py::arg("src_length"));
+
   us.def(
       "compare_code_point_order_between",
       [](const UnicodeString &self, int32_t start, int32_t limit, const _UnicodeStringVariant &src_text,
@@ -346,8 +375,11 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
         return self.compareCodePointOrderBetween(start, limit, VARIANT_TO_UNISTR(src_text), src_start, src_limit);
       },
       py::arg("start"), py::arg("limit"), py::arg("src_text"), py::arg("src_start"), py::arg("src_limit"));
+
   us.def("copy", &UnicodeString::copy, py::arg("start"), py::arg("limit"), py::arg("dest"));
+
   us.def("count_char32", &UnicodeString::countChar32, py::arg("start ") = 0, py::arg("length") = INT32_MAX);
+
   us.def(
         // [1] endsWith(const char16_t *srcChars, int32_t srcStart, int32_t srcLength)
         "ends_with", py::overload_cast<const char16_t *, int32_t, int32_t>(&UnicodeString::endsWith, py::const_),
@@ -370,6 +402,7 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
             return self.endsWith(src_chars, src_length);
           },
           py::arg("src_chars"), py::arg("src_length"));
+
   us.def(
         // [1] extract(char *dest, int32_t destCapacity, UConverter *cnv, UErrorCode &errorCode)
         "extract",
@@ -441,6 +474,7 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
             return py::bytes(target.data(), length);
           },
           py::arg("start"), py::arg("start_length"));
+
   us.def(
         // [1] extractBetween(int32_t start, int32_t limit, char16_t *dst, int32_t dstStart = 0)
         "extract_between",
@@ -457,7 +491,9 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
           "extract_between",
           py::overload_cast<int32_t, int32_t, UnicodeString &>(&UnicodeString::extractBetween, py::const_),
           py::arg("start"), py::arg("limit"), py::arg("target"));
+
   us.def("fast_copy_from", &UnicodeString::fastCopyFrom, py::arg("src"));
+
   us.def(
         // [1] findAndReplace(const UnicodeString &oldText, const UnicodeString &newText)
         "find_and_replace",
@@ -487,7 +523,9 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
           },
           py::arg("start"), py::arg("length"), py::arg("old_text"), py::arg("old_start"), py::arg("old_length"),
           py::arg("new_text"), py::arg("new_start"), py::arg("new_length"));
+
   us.def("fold_case", &UnicodeString::foldCase, py::arg("options") = 0);
+
   us.def_static(
       "from_utf32",
       [](const std::u32string utf32, int32_t length) {
@@ -495,8 +533,10 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
         return UnicodeString::fromUTF32(p, length);
       },
       py::arg("utf32"), py::arg("length"));
+
   us.def_static(
       "from_utf8", [](const char *utf8) { return UnicodeString::fromUTF8(StringPiece(utf8)); }, py::arg("utf8"));
+
   us.def(
       "get_buffer",
       [](const UnicodeString &self) -> std::optional<std::unique_ptr<_ConstChar16Ptr>> {
@@ -507,9 +547,13 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
         return std::make_unique<_ConstChar16Ptr>(p);
       },
       py::return_value_policy::reference);
+
   us.def("get_capacity", &UnicodeString::getCapacity);
+
   us.def("get_char32_limit", &UnicodeString::getChar32Limit, py::arg("offset"));
+
   us.def("get_char32_start", &UnicodeString::getChar32Start, py::arg("offset"));
+
   us.def(
       "get_terminated_buffer",
       [](UnicodeString &self) -> std::optional<std::unique_ptr<_ConstChar16Ptr>> {
@@ -520,9 +564,19 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
         return std::make_unique<_ConstChar16Ptr>(p);
       },
       py::return_value_policy::reference);
+
+  us.def(
+      "handle_replace_between",
+      [](UnicodeString &self, int32_t start, int32_t limit, const _UnicodeStringVariant &text) {
+        self.handleReplaceBetween(start, limit, VARIANT_TO_UNISTR(text));
+      },
+      py::arg("start"), py::arg("limit"), py::arg("text"));
+
   us.def("hash_code", &UnicodeString::hashCode);
+
   us.def("has_more_char32_than", &UnicodeString::hasMoreChar32Than, py::arg("start"), py::arg("length"),
          py::arg("number"));
+
   us.def(
         // [4] indexOf(const char16_t *srcChars, int32_t srcLength, int32_t start)
         "index_of", py::overload_cast<const char16_t *, int32_t, int32_t>(&UnicodeString::indexOf, py::const_),
@@ -575,6 +629,7 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
           // [13] indexOf(UChar32 c, int32_t start, int32_t length)
           "index_of", py::overload_cast<UChar32, int32_t, int32_t>(&UnicodeString::indexOf, py::const_), py::arg("c"),
           py::arg("start"), py::arg("length"));
+
   us.def(
         // [2] insert(int32_t start, const char16_t *srcChars, int32_t srcStart, int32_t srcLength)
         "insert", py::overload_cast<int32_t, const char16_t *, int32_t, int32_t>(&UnicodeString::insert),
@@ -600,8 +655,11 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
       .def(
           // [6] insert(int32_t start, UChar32 srcChar)
           "insert", py::overload_cast<int32_t, UChar32>(&UnicodeString::insert), py::arg("start"), py::arg("src_char"));
+
   us.def("is_bogus", &UnicodeString::isBogus);
+
   us.def("is_empty", &UnicodeString::isEmpty);
+
   us.def(
         // [4] lastIndexOf(const char16_t *srcChars, int32_t srcLength, int32_t start)
         "last_index_of", py::overload_cast<const char16_t *, int32_t, int32_t>(&UnicodeString::lastIndexOf, py::const_),
@@ -657,23 +715,29 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
           // [13] lastIndexOf(UChar32 c, int32_t start, int32_t length)
           "last_index_of", py::overload_cast<UChar32, int32_t, int32_t>(&UnicodeString::lastIndexOf, py::const_),
           py::arg("c"), py::arg("start"), py::arg("length"));
+
   us.def("move_index32", &UnicodeString::moveIndex32, py::arg("index"), py::arg("delta"));
+
   us.def(
       "pad_leading",
       [](UnicodeString &self, int32_t target_length, uint16_t pad_char) {
         return self.padLeading(target_length, pad_char);
       },
       py::arg("target_length"), py::arg("pad_char") = 0x20);
+
   us.def(
       "pad_trailing",
       [](UnicodeString &self, int32_t target_length, uint16_t pad_char) {
         return self.padTrailing(target_length, pad_char);
       },
       py::arg("target_length"), py::arg("pad_char") = 0x20);
+
   us.def("remove", py::overload_cast<>(&UnicodeString::remove))
       .def("remove", py::overload_cast<int32_t, int32_t>(&UnicodeString::remove), py::arg("start"),
            py::arg("length") = INT32_MAX);
+
   us.def("remove_between", &UnicodeString::removeBetween, py::arg("start"), py::arg("limit") = INT32_MAX);
+
   us.def(
         // [2] replace(int32_t start, int32_t length, const char16_t *srcChars, int32_t srcStart, int32_t srcLength)
         "replace", py::overload_cast<int32_t, int32_t, const char16_t *, int32_t, int32_t>(&UnicodeString::replace),
@@ -700,6 +764,7 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
           // [6] replace(int32_t start, int32_t length, UChar32 srcChar)
           "replace", py::overload_cast<int32_t, int32_t, UChar32>(&UnicodeString::replace), py::arg("start"),
           py::arg("length"), py::arg("src_char"));
+
   us.def(
         // [1] replaceBetween(int32_t start, int32_t limit, const UnicodeString &srcText)
         "replace_between",
@@ -715,13 +780,17 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
             return self.replaceBetween(start, limit, VARIANT_TO_UNISTR(src_text), src_start, src_limit);
           },
           py::arg("start"), py::arg("limit"), py::arg("src_text"), py::arg("src_start"), py::arg("src_limit"));
+
   us.def("retain_between", &UnicodeString::retainBetween, py::arg("start"), py::arg("limit") = INT32_MAX);
+
   us.def("reverse", py::overload_cast<int32_t, int32_t>(&UnicodeString::reverse), py::arg("start"), py::arg("length"))
       .def("reverse", py::overload_cast<>(&UnicodeString::reverse));
+
   us.def(
       "set_char_at",
       [](UnicodeString &self, int32_t offset, uint16_t ch) -> UnicodeString & { return self.setCharAt(offset, ch); },
       py::arg("offset"), py::arg("ch"));
+
   us.def(
         // [3] setTo(const char16_t *srcChars, int32_t srcLength)
         "set_to", py::overload_cast<const char16_t *, int32_t>(&UnicodeString::setTo), py::arg("src_chars"),
@@ -752,7 +821,9 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
       .def(
           // [8] setTo(UChar32 srcChar)
           "set_to", py::overload_cast<UChar32>(&UnicodeString::setTo), py::arg("src_char"));
+
   us.def("set_to_bogus", &UnicodeString::setToBogus);
+
   us.def(
         // [1] startsWith(const char16_t *srcChars, int32_t srcStart, int32_t srcLength)
         "starts_with", py::overload_cast<const char16_t *, int32_t, int32_t>(&UnicodeString::startsWith, py::const_),
@@ -776,12 +847,16 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
             return self.startsWith(src_chars, src_length);
           },
           py::arg("src_chars"), py::arg("src_length"));
+
 #if (U_ICU_VERSION_MAJOR_NUM >= 56)
   us.def("swap", &UnicodeString::swap, py::arg("other"));
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 56)
+
   us.def("temp_sub_string", &UnicodeString::tempSubString, py::arg("start") = 0, py::arg("length") = INT32_MAX);
+
   us.def("temp_sub_string_between", &UnicodeString::tempSubStringBetween, py::arg("start") = 0,
          py::arg("limit") = INT32_MAX);
+
   us.def(
         "to_lower",
         [](UnicodeString &self, const _LocaleVariant &locale) -> UnicodeString & {
@@ -789,6 +864,7 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
         },
         py::arg("locale"))
       .def("to_lower", py::overload_cast<>(&UnicodeString::toLower));
+
   us.def("to_title", py::overload_cast<BreakIterator *>(&UnicodeString::toTitle), py::arg("title_iter"))
       .def(
           "to_title",
@@ -801,6 +877,7 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
           [](UnicodeString &self, BreakIterator *title_iter, const _LocaleVariant &locale, uint32_t options)
               -> UnicodeString & { return self.toTitle(title_iter, VARIANT_TO_LOCALE(locale), options); },
           py::arg("title_iter"), py::arg("locale"), py::arg("options"));
+
   us.def(
         "to_upper",
         [](UnicodeString &self, const _LocaleVariant &locale) -> UnicodeString & {
@@ -808,6 +885,7 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
         },
         py::arg("locale"))
       .def("to_upper", py::overload_cast<>(&UnicodeString::toUpper));
+
   us.def("to_utf32", [](const UnicodeString &self) {
     ErrorCode error_code;
     const auto length = self.toUTF32(nullptr, 0, error_code);
@@ -819,36 +897,54 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
     }
     return std::u32string(dest.begin(), dest.end());
   });
+
   us.def("to_utf8", [](const UnicodeString &self) {
     std::string result;
     auto sink = StringByteSink(&result);
     self.toUTF8(sink);
     return py::bytes(result.c_str(), result.size());
   });
+
   us.def("to_utf8_string", [](const UnicodeString &self) {
     std::string result;
     self.toUTF8String(result);
     return result;
   });
+
   us.def("trim", &UnicodeString::trim);
+
   us.def("truncate", &UnicodeString::truncate, py::arg("target_length"));
-  us.def("unescape", &UnicodeString::unescape).def("unescape_at", &UnicodeString::unescapeAt, py::arg("offset"));
 
-  us.def_property_readonly_static("SENTINEL", [](py::object) { return U_SENTINEL; });
+  us.def("unescape", &UnicodeString::unescape);
+
+  us.def("unescape_at", &UnicodeString::unescapeAt, py::arg("offset"));
+
+  us.def_property_readonly_static("SENTINEL", [](const py::object &) { return U_SENTINEL; });
+
+  us.def_property_readonly_static("COMPARE_CODE_POINT_ORDER",
+                                  [](const py::object &) { return U_COMPARE_CODE_POINT_ORDER; });
+
+  us.def_property_readonly_static("FOLD_CASE_DEFAULT", [](const py::object &) { return U_FOLD_CASE_DEFAULT; });
 
-  us.def_property_readonly_static("COMPARE_CODE_POINT_ORDER", [](py::object) { return U_COMPARE_CODE_POINT_ORDER; });
-  us.def_property_readonly_static("FOLD_CASE_DEFAULT", [](py::object) { return U_FOLD_CASE_DEFAULT; });
   us.def_property_readonly_static("FOLD_CASE_EXCLUDE_SPECIAL_I",
-                                  [](py::object) { return U_FOLD_CASE_EXCLUDE_SPECIAL_I; });
+                                  [](const py::object &) { return U_FOLD_CASE_EXCLUDE_SPECIAL_I; });
+
 #if (U_ICU_VERSION_MAJOR_NUM >= 60)
-  us.def_property_readonly_static("TITLECASE_ADJUST_TO_CASED", [](py::object) { return U_TITLECASE_ADJUST_TO_CASED; });
+  us.def_property_readonly_static("TITLECASE_ADJUST_TO_CASED",
+                                  [](const py::object &) { return U_TITLECASE_ADJUST_TO_CASED; });
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 60)
+
   us.def_property_readonly_static("TITLECASE_NO_BREAK_ADJUSTMENT",
-                                  [](py::object) { return U_TITLECASE_NO_BREAK_ADJUSTMENT; });
-  us.def_property_readonly_static("TITLECASE_NO_LOWERCASE", [](py::object) { return U_TITLECASE_NO_LOWERCASE; });
+                                  [](const py::object &) { return U_TITLECASE_NO_BREAK_ADJUSTMENT; });
+
+  us.def_property_readonly_static("TITLECASE_NO_LOWERCASE",
+                                  [](const py::object &) { return U_TITLECASE_NO_LOWERCASE; });
+
 #if (U_ICU_VERSION_MAJOR_NUM >= 60)
-  us.def_property_readonly_static("TITLECASE_SENTENCES", [](py::object) { return U_TITLECASE_SENTENCES; });
-  us.def_property_readonly_static("TITLECASE_WHOLE_STRING", [](py::object) { return U_TITLECASE_WHOLE_STRING; });
+  us.def_property_readonly_static("TITLECASE_SENTENCES", [](const py::object &) { return U_TITLECASE_SENTENCES; });
+
+  us.def_property_readonly_static("TITLECASE_WHOLE_STRING",
+                                  [](const py::object &) { return U_TITLECASE_WHOLE_STRING; });
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 60)
 
   m.attr("US_INV") = US_INV;
