@@ -12,6 +12,7 @@ from icupy.icu import (
 def test_api():
     sym = DateFormatSymbols(Locale.get_japan())
     sym2 = DateFormatSymbols(Locale("und"))
+    sym3 = DateFormatSymbols("ja_JP")
 
     # Locale icu::DateFormatSymbols::getLocale(
     #       ULocDataLocaleType type,
@@ -21,6 +22,9 @@ def test_api():
     assert isinstance(locale, Locale)
     assert locale == Locale("ja_JP")
 
+    locale2 = sym3.get_locale(ULocDataLocaleType.ULOC_VALID_LOCALE)
+    assert locale2 == locale
+
     # UnicodeString &icu::DateFormatSymbols::getLocalPatternChars(
     #       UnicodeString &result
     # )
@@ -48,6 +52,12 @@ def test_api():
 
 
 def test_date_format_symbols():
+    locale = (
+        Locale("en_US")
+        if str(Locale.get_default()) == "ja_JP"
+        else Locale("ja_JP")
+    )
+
     # [1]
     # icu::DateFormatSymbols::DateFormatSymbols(UErrorCode &status)
     sym1 = DateFormatSymbols()
@@ -57,7 +67,7 @@ def test_date_format_symbols():
     #       const Locale &locale,
     #       UErrorCode &status
     # )
-    sym2 = DateFormatSymbols(Locale.get_us())
+    sym2 = DateFormatSymbols(locale)
 
     # [5]
     # icu::DateFormatSymbols::DateFormatSymbols(const DateFormatSymbols &)
