@@ -186,7 +186,10 @@ def test_api():
     assert test2.is_bogus()
 
     # UnicodeSet.__repr__() -> str
-    assert repr(test1) == "UnicodeSet([0-9])"
+    assert repr(test1) == "<UnicodeSet('[0-9]')>"
+
+    test3 = UnicodeSet(0, 16).add_all("'\"\\")
+    assert repr(test3) == "<UnicodeSet('[\\u0000-\\u0010\"\\'\\\\]')>"
 
 
 def test_apply_int_property_value():
@@ -593,9 +596,15 @@ def test_hash_code():
     # int32_t icu::UnicodeSet::hashCode(void)
     assert test1.hash_code() != test2.hash_code()
 
+    assert hash(test1) == test1.hash_code()
+    assert hash(test2) == test2.hash_code()
+
     test2.add(0x30, 0x39)
     assert test1.hash_code() == test2.hash_code()
 
+    assert hash(test1) == test1.hash_code()
+    assert hash(test2) == test2.hash_code()
+
 
 @pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 70, reason="ICU4C<70")
 def test_has_strings():
