@@ -887,10 +887,13 @@ def test_from_utf8():
     assert str(test1) == s3
 
     # UnicodeString.__repr__() -> str
-    assert repr(test1) == "UnicodeString('a\\U0001f338b')"
+    assert repr(test1) == "UnicodeString('a\\U0001f338b', text_length=4)"
 
     test2 = UnicodeString.from_utf8(b"'Julius\tC\xd3\x95sar'")
-    assert repr(test2) == "UnicodeString('\\'Julius\\x09C\\u04d5sar\\'')"
+    assert (
+        repr(test2)
+        == "UnicodeString('\\'Julius\\x09C\\u04d5sar\\'', text_length=14)"
+    )
 
 
 def test_get_buffer():
@@ -922,6 +925,25 @@ def test_get_buffer():
     assert test1.get_terminated_buffer() is None
 
 
+def test_handle_replace_between():
+    # virtual void icu::UnicodeString::handleReplaceBetween(
+    #       int32_t start,
+    #       int32_t limit,
+    #       const UnicodeString &text
+    # )
+    test1 = UnicodeString("foo bar baz")
+    test1.handle_replace_between(4, 7, UnicodeString("BAR"))
+    test1.handle_replace_between(8, 11, UnicodeString("BAZ"))
+    test1.handle_replace_between(0, 3, UnicodeString("FOO"))
+    assert test1 == "FOO BAR BAZ"
+
+    test1 = UnicodeString("foo bar baz")
+    test1.handle_replace_between(4, 7, "BAR")
+    test1.handle_replace_between(8, 11, "BAZ")
+    test1.handle_replace_between(0, 3, "FOO")
+    assert test1 == "FOO BAR BAZ"
+
+
 def test_hash_code():
     test1 = UnicodeString("abc")
     test2 = UnicodeString("abc")
@@ -929,12 +951,21 @@ def test_hash_code():
     # int32_t icu::UnicodeString::hashCode(void)
     assert test1.hash_code() == test2.hash_code()
 
+    assert hash(test1) == test1.hash_code()
+    assert hash(test2) == test2.hash_code()
+
     test1.append("d")
     assert test1.hash_code() != test2.hash_code()
 
+    assert hash(test1) == test1.hash_code()
+    assert hash(test2) == test2.hash_code()
+
     test2.append("d")
     assert test1.hash_code() == test2.hash_code()
 
+    assert hash(test1) == test1.hash_code()
+    assert hash(test2) == test2.hash_code()
+
 
 def test_index_of():
     raw_text = (
