@@ -1,9 +1,11 @@
+# fmt: off
 from icupy.icu import (
-    U_SHAPE_DIGITS_AN2EN, U_SHAPE_DIGITS_EN2AN,
     U_SHAPE_DIGIT_TYPE_AN, U_SHAPE_DIGIT_TYPE_AN_EXTENDED,
-    u_shape_arabic,
+    U_SHAPE_DIGITS_AN2EN, U_SHAPE_DIGITS_EN2AN, u_shape_arabic,
 )
 
+# fmt: on
+
 
 def test_api():
     # From icu/source/test/cintltst/cbiditst.c
