@@ -1,8 +1,11 @@
+# fmt: off
 from icupy.icu import (
-    UDateTimeScale, UTimeScaleValue,
-    utmscale_from_int64, utmscale_get_time_scale_value, utmscale_to_int64,
+    UDateTimeScale, UTimeScaleValue, utmscale_from_int64,
+    utmscale_get_time_scale_value, utmscale_to_int64,
 )
 
+# fmt: on
+
 
 def test_api():
     # int64_t utmscale_getTimeScaleValue(
@@ -11,7 +14,8 @@ def test_api():
     #       UErrorCode *status
     # )
     from_min = utmscale_get_time_scale_value(
-        UDateTimeScale.UDTS_JAVA_TIME, UTimeScaleValue.UTSV_FROM_MIN_VALUE)
+        UDateTimeScale.UDTS_JAVA_TIME, UTimeScaleValue.UTSV_FROM_MIN_VALUE
+    )
     assert isinstance(from_min, int)
 
     # int64_t utmscale_fromInt64(
@@ -20,7 +24,8 @@ def test_api():
     #       UErrorCode *status
     # )
     universal_time = utmscale_from_int64(
-        from_min, UDateTimeScale.UDTS_JAVA_TIME)
+        from_min, UDateTimeScale.UDTS_JAVA_TIME
+    )
     assert isinstance(universal_time, int)
 
     # int64_t utmscale_toInt64(
